from wrapper import get, run
import logging
import requests


@get('/')
def f(*args, **kwargs):
    return '<html><head></head><body><h1>Hello!</h1></body></html>'

@get('/test', ['php'])
def test_f(*args, **kwargs):
    arguments = kwargs['arguments']
    php = arguments['php'][0]

    self = args[0]
    self.write("Head")

    return 'Test{}'.format(php)

def test():
    run(8888)

def main():
    pass


if __name__ == '__main__':
    test()


import tornado.web
import tornado.ioloop
import tornado.concurrent

import logging

path_maps = {
    
}

class get(object):
    def __init__(self, path, names=None):
        global path_maps

        self.path = path
        path_maps[path] = self
        self.function = None

        if names is None:
            names = []
        
        self.argument_names = names
        

        
    def __call__(self, *args, **kwargs):
        global path_maps

        if len(args) > 0:
            self.function = args[0]
                
        def funct(self_, *args, **kwargs):

            arguments = {name : self_.get_arguments(name) for name in self.argument_names}
            
            kwargs['arguments'] = arguments

            stuff = self.function(self_, *args, **kwargs)
            self_.write(stuff)

        path_maps[self.path] = funct
        return funct


def paths_to_handlers():
    global path_maps

    handlers = []

    for path, handler in path_maps.items():
        handler_class = type(
                            path + 'Handler', 
                            (tornado.web.RequestHandler, object), 
                            dict(get=handler)
        )


        handlers.append((path, handler_class))

    return handlers



def run(port_number=80):

    logging.info('Adding handlers')
    application = tornado.web.Application(paths_to_handlers())
    
    logging.info('Listening on port {}'.format(port_number))
    application.listen(port_number)

    logging.info('Main loop starting')
    tornado.ioloop.IOLoop.instance().start()



#!/usr/bin/env python

try:
    from setuptools import setup, find_packages
except ImportError:
    from distribute_setup import use_setuptools
    use_setuptools()
    from setuptools import setup, find_packages

try:
    license = open('LICENSE').read()
except:
    license = None

try:
    readme = open('README.me').read()
except:
    readme = None

setup(
    name='just-columns',
    version='0.0.1',
    author='enalicho',
    author_email='enalicho@gmail.com',
    packages=['just-columns'],
    scripts=[],
    url='http://github.com/eeue56/just-columns',
    license=license,
    description='',
    long_description=readme,
    requires=['tornado'],
    install_requires=[
        'tornado >= 2.2.0'
    ]
)